Skip to contents

BADM_IC_process

Usage

BADM_IC_process(settings, dir, overwrite = TRUE)

Arguments

settings

pecan xml settings

dir

output dir which you want to store the IC netcdf file

overwrite

Flag for overwriting the IC file.

Value

a list of paths to generated and stored IC files.

Examples

if (FALSE) { # \dontrun{
settings <- PEcAn.settings::read.settings("pecan.xml")
output_dir <- withr::local_tempdir()

ic_files <- BADM_IC_process(settings, dir = output_dir)
} # }