Create SIPNET event files from water balance data
Source:R/irrigation-event-files.R
create_event_file.RdAggregates irrigation to weekly values and formats for SIPNET. Irrigation is summed by week and reported on the first day of each week. Units are converted from mm to cm.