Skip to contents

Recommended nitrogen fertilizer application rates for California crops. When multiple sources report rates for the same crop the value is the envelope across sources. Crops reported only as within year stages (Barley, Beans, Cauliflower, Melons) have stages summed to an annual total. Crops reported only by age (Almonds) get the envelope across ages.

Usage

ca_n_application_rate

Format

A tibble with one row per crop and the columns:

pft_group

Plant functional type group: "row", "woody", or "rice".

crop

Crop name as given in the source.

min_n_lbs_acre, max_n_lbs_acre

Recommended N rate range (lbs N / acre).

source

Short citation. Multiple sources are joined with "; ".

min_n_g_m2, max_n_g_m2

Same range in SI units (g N / m\(^2\)).

Rosenstock, T. S., Liptzin, D., Six, J., Tomich, T. P. (2013). Nitrogen fertilizer use in California: Assessing the data, trends and a way forward. California Agriculture 67(1). https://escholarship.org/uc/item/5mk2q1sm

Meyer, R. D., Marcum, D. B., Orloff, S. B., Schmierer, J. L. (2007). Alfalfa fertilization strategies. UC ANR Publication 8292.

Brown, P. H. et al. (2020). Nitrogen Best Management Practices for Almonds. Almond Board of California. Source for Almonds rates by age.

Lazicki, P., Geisseler, D., Horwath, W. R. (2016). Potato Production in California. CDFA FREP / UC Davis. Source for Potato.

See also