Maximum effective rooting depth and minimum soil water content thresholds for various crops. The `whc_min_frac` column represents the fraction of total available water (TAW) that should remain in the root zone to avoid moisture stress (equivalent to 1 - p, where p is the depletion fraction from FAO-56).
Format
A tibble with one row per crop and the following columns:
- crop_number
BIS crop number (character). Blank for crops not in BIS.
- crop_name
Crop name.
- Category
Crop category (e.g., Woody Perennial, Annual (Hardy)).
- rooting_depth_m
Maximum effective rooting depth in meters.
- whc_min_frac
Minimum soil water as fraction of available water-holding capacity (0-1).
- whc_notes
Rationale or source for the minimum WHC value.
- rooting_depth_notes
Rationale or source for the rooting depth value.
Allen, R. G., Pereira, L. S., Raes, D., & Smith, M. FAO Irrigation and Drainage Paper No. 56: Crop evapotranspiration. Chapter 8. Table 22. https://www.fao.org/4/x0490e/x0490e0e.htm#chapter
Examples
data(crop_whc)
head(crop_whc)
#> # A tibble: 6 × 7
#> crop_number crop_name Category rooting_depth_m whc_min_frac whc_notes
#> <chr> <chr> <chr> <dbl> <dbl> <chr>
#> 1 2.01 Alfalfa (annual) Non-woody… 1.5 0.45 FAO-56 T…
#> 2 1.01 Alfalfa (cycle) Non-woody… 2 0.4 FAO-56 T…
#> 3 3.01 Almonds Woody Per… 1.5 0.6 FAO-56 T…
#> 4 3.02 Apple Woody Per… 1.5 0.5 FAO-56 T…
#> 5 1.02 Artichokes Non-woody… 0.75 0.55 FAO-56 T…
#> 6 1.03 Asparagus Non-woody… 1.5 0.55 FAO-56 T…
#> # ℹ 1 more variable: rooting_depth_notes <chr>