Returns recommended nitrogen application rate ranges for California crops. Rates are provided in both imperial (lbs N/acre) and SI (g N/m2) units.
Usage
look_up_ca_n_rate(crop, pft_group = NULL, unit = c("g_m2", "lbs_acre"))Source
Rosenstock, T. S., Liptzin, D., Six, J., & Tomich, T. P. (2013). Nitrogen fertilizer use in California: Assessing the data, trends and a way forward. California Agriculture, 67(1). https://escholarship.org/uc/item/5mk2q1sm
Meyer, R. D., Marcum, D. B., Orloff, S. B., & Schmierer, J. L. (2007). Alfalfa fertilization strategies. UC ANR Publication 8296.
Value
A tibble with columns: `pft_group`, `crop`, `min_n`, `max_n`, `source`. The `min_n` and `max_n` columns are in the requested unit. Returns an empty tibble (with warning) if no match is found.
Details
Matching is case-insensitive. Exact matches are returned directly. If no exact match is found, partial matching is used to suggest possible crops and an empty data frame is returned.
See also
[look_up_fertilizer_components()] for fertilizer nutrient composition (N/C fractions) from the SWAT/DayCent database. [ca_n_application_rate] for the underlying dataset.
Examples
look_up_ca_n_rate("Tomatoes, Processing")
#> # A tibble: 1 × 5
#> pft_group crop min_n max_n source
#> <chr> <chr> <dbl> <dbl> <chr>
#> 1 row Tomatoes, processing 11.2 16.8 Rosenstock et al., 2013
look_up_ca_n_rate("corn")
#> # A tibble: 1 × 5
#> pft_group crop min_n max_n source
#> <chr> <chr> <dbl> <dbl> <chr>
#> 1 row Corn 16.8 30.8 Rosenstock et al., 2013
look_up_ca_n_rate("wheat", unit = "lbs_acre")
#> # A tibble: 1 × 5
#> pft_group crop min_n max_n source
#> <chr> <chr> <dbl> <dbl> <chr>
#> 1 row Wheat 100 240 Rosenstock et al., 2013
look_up_ca_n_rate("pistachios", pft_group = "woody")
#> # A tibble: 1 × 5
#> pft_group crop min_n max_n source
#> <chr> <chr> <dbl> <dbl> <chr>
#> 1 woody Pistachios 11.2 25.2 Rosenstock et al., 2013